#!/bin/bash

# Copyright (C) 2018-2021 Intel Corporation
# SPDX-License-Identifier: Apache-2.0


docker pull intel/intel-optimized-pytorch
echo -e "\e[1;32mpytorch is pulled successfully\e[0m"
echo -e "\e[1;36mTo view the image : docker images\e[0m"
echo -e "\e[1;31mFor further queries please follow below URL\e[0m"
echo -e "\e[1;32m\nhttps://hub.docker.com/r/intel/intel-optimized-pytorch\e[0m"

